==> nextcloud-27.1.11.tgz: nextcloud/apps/suspicious_login/l10n/nl.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nieuwe inloglocatie opgemerkt",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Je kunt meer informatie krijgen door op de knop te drukken die %s opent en informatie weergeeft over het verdachte IP-adres.",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "We hebben een nieuwe inlog-poging bij je account opgemerkt. Het IP-adres %s is als verdacht aangemerkt. Als jij het was, kun je dit bericht negeren. Zo niet dan kun je het beste je wachtwoord aanpassen.",
    "More information ↗" : "Meer informatie ↗",
    "Suspicious Login" : "Verdachte login",
    "New login detected" : "Nieuwe inlogpoging opgemerkt",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detecteer en waarschuw voor inlogpogingen bij Nextcloud vanaf verdachte IP-adressen.",
    "Suspicious login detection" : "Detectie verdachte inlogpogingen",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "De 'verdachte inlogpogingen'-app is ingeschakeld voor deze Nextcloud server. Het houdt de IP-adressen vanwaar gebruikers succesvol hebben ingelogd, en waarschuwt wanneer er wordt ingelogd vanaf een verdacht IP-adres.",
    "Training data statistics" : "Trainingsgegevens statistieken",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Tot nog toe verzamelde de app {total} aantal inlog (inclusief client verbindingen), waarvan {distinct} distinct zijn (IP, UID) elementen.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Classificatiemodel statistieken",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Er is nog geen classificatiemodel getrained. Dit betekent vermoedelijk dat je de app recent hebt ingeschakeld. Omdat het trainen van een model veel goede gegevens vereist, wacht de app tot minimaal {days} dagen inloginformatie is verzameld.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Tijdens de evaluatie, heeft het laatste model (trained {time}) nu al {recall}% van alle verdachte logins gezien (recall), waarbij {precision}% van de als verdachte logins inderdaad verdacht moeten worden beschouwd (precision). Hieronder een visualisatie van het de historisch model prestaties.",
    "Precision" : "Precisie",
    "Recall" : "Terughalen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/nl.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nieuwe inloglocatie opgemerkt",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "We hebben een nieuwe inlog-poging bij je account opgemerkt. Het IP-adres %s is als verdacht aangemerkt. Als jij het was, kun je dit bericht negeren. Zo niet dan kun je het beste je wachtwoord aanpassen.",
    "Suspicious Login" : "Verdachte login",
    "New login detected" : "Nieuwe inlogpoging opgemerkt",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detecteer en waarschuw voor inlogpogingen bij Nextcloud vanaf verdachte IP-adressen.",
    "Suspicious login detection" : "Detectie verdachte inlogpogingen",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "De 'verdachte inlogpogingen'-app is ingeschakeld voor deze Nextcloud server. Het houdt de IP-adressen vanwaar gebruikers succesvol hebben ingelogd, en waarschuwt wanneer er wordt ingelogd vanaf een verdacht IP-adres.",
    "Training data statistics" : "Trainingsgegevens statistieken",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Tot nog toe verzamelde de app {total} aantal inlog (inclusief client verbindingen), waarvan {distinct} distinct zijn (IP, UID) elementen.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Classificatiemodel statistieken",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Er is nog geen classificatiemodel getrained. Dit betekent vermoedelijk dat je de app recent hebt ingeschakeld. Omdat het trainen van een model veel goede gegevens vereist, wacht de app tot minimaal {days} dagen inloginformatie is verzameld.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Tijdens de evaluatie, heeft het laatste model (trained {time}) nu al {recall}% van alle verdachte logins gezien (recall), waarbij {precision}% van de als verdachte logins inderdaad verdacht moeten worden beschouwd (precision). Hieronder een visualisatie van het de historisch model prestaties.",
    "Precision" : "Precisie",
    "Recall" : "Terughalen",
    "More information ↗" : "Meer informatie ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Je kunt meer informatie krijgen door op de knop te drukken die %s opent en informatie weergeeft over het verdachte IP-adres."
},
"nplurals=2; plural=(n != 1);");
